"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.distinct = void 0;
const shared_1 = require("../../shared");
const BasicAsyncEnumerable_1 = require("../BasicAsyncEnumerable");
/**
 * Returns distinct elements from a sequence by using the default or specified equality comparer to compare values.
 * @param source The sequence to remove duplicate elements from.
 * @param comparer An IEqualityComparer<T> to compare values. Optional. Defaults to Strict Equality Comparison.
 * @returns An IAsyncEnumerable<T> that contains distinct elements from the source sequence.
 */
function distinct(source, comparer = shared_1.StrictEqualityComparer) {
    async function* iterator() {
        const distinctElements = [];
        for await (const item of source) {
            const foundItem = distinctElements.find((x) => comparer(x, item));
            if (!foundItem) {
                distinctElements.push(item);
                yield item;
            }
        }
    }
    return new BasicAsyncEnumerable_1.BasicAsyncEnumerable(iterator);
}
exports.distinct = distinct;
