"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.eachAsync = void 0;
const BasicAsyncEnumerable_1 = require("../BasicAsyncEnumerable");
/**
 * Performs a specified action on each element of the AsyncIterable<TSource>
 * @param source The source to iterate
 * @param action The action to take an each element
 * @returns A new IAsyncEnumerable<T> that executes the action lazily as you iterate.
 */
exports.eachAsync = (source, action) => {
    async function* iterator() {
        for await (const value of source) {
            await action(value);
            yield value;
        }
    }
    return new BasicAsyncEnumerable_1.BasicAsyncEnumerable(iterator);
};
