"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.contains = void 0;
const shared_1 = require("../../shared");
const _nextIteration_1 = require("./_nextIteration");
/**
 * Determines whether a sequence contains a specified element by using the specified or default IEqualityComparer<T>.
 * @param source A sequence in which to locate a value.
 * @param value The value to locate in the sequence.
 * @param comparer An equality comparer to compare values. Optional.
 * @returns Whether or not source contains the specified value
 */
async function contains(source, value, comparer = shared_1.StrictEqualityComparer) {
    let values;
    if (comparer) {
        values = _nextIteration_1.nextIteration(source, (x) => comparer(value, x));
    }
    else {
        values = _nextIteration_1.nextIteration(source, (x) => x === value);
    }
    switch (values.type) {
        case 0 /* PromiseToArray */: {
            const data = await values.generator();
            return data.some((x) => x);
        }
        case 1 /* ArrayOfPromises */: {
            const data = await Promise.all(values.generator());
            return data.some((x) => x);
        }
        case 2 /* PromiseOfPromises */: {
            const data = await Promise.all(await values.generator());
            return data.some((x) => x);
        }
    }
}
exports.contains = contains;
