"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.selectMany = void 0;
const BasicParallelEnumerable_1 = require("../BasicParallelEnumerable");
const _nextIteration_1 = require("./_nextIteration");
const _nextIterationWithIndex_1 = require("./_nextIterationWithIndex");
function selectMany(source, selector) {
    const generator = async () => {
        let values;
        if (typeof selector === "function") {
            if (selector.length === 1) {
                values = _nextIteration_1.nextIteration(source, selector);
            }
            else {
                values = _nextIterationWithIndex_1.nextIterationWithIndex(source, selector);
            }
        }
        else {
            // eslint-disable-next-line @typescript-eslint/no-unsafe-return, @typescript-eslint/no-unsafe-member-access
            values = _nextIteration_1.nextIteration(source, (x) => x[selector]);
        }
        const valuesArray = [];
        switch (values.type) {
            case 0 /* PromiseToArray */: {
                for (const outer of await values.generator()) {
                    for (const y of outer) {
                        valuesArray.push(y);
                    }
                }
                break;
            }
            case 1 /* ArrayOfPromises */: {
                for (const outer of values.generator()) {
                    for (const y of await outer) {
                        valuesArray.push(y);
                    }
                }
                break;
            }
            case 2 /* PromiseOfPromises */: {
                for (const outer of await values.generator()) {
                    for (const y of await outer) {
                        valuesArray.push(y);
                    }
                }
                break;
            }
        }
        return valuesArray;
    };
    return new BasicParallelEnumerable_1.BasicParallelEnumerable({
        generator,
        type: 0 /* PromiseToArray */,
    });
}
exports.selectMany = selectMany;
