"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isParallelEnumerable = void 0;
const BasicParallelEnumerable_1 = require("./BasicParallelEnumerable");
/* eslint-disable @typescript-eslint/no-unsafe-member-access, @typescript-eslint/no-unsafe-assignment */
/**
 * Determine if the source is IParallelEnumerable
 * @param source Any value
 * @returns Whether or not this type is a Parallel Enumerable
 */
exports.isParallelEnumerable = (source) => {
    if (!source) {
        return false;
    }
    if (source instanceof BasicParallelEnumerable_1.BasicParallelEnumerable) {
        return true;
    }
    if (typeof source[Symbol.asyncIterator] !== "function") {
        return false;
    }
    const propertyNames = Object.getOwnPropertyNames(BasicParallelEnumerable_1.BasicParallelEnumerable.prototype)
        .filter((v) => v !== "constructor");
    const methods = source.prototype || source;
    for (const prop of propertyNames) {
        if (typeof methods[prop] !== "function") {
            return false;
        }
    }
    return true;
};
