"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.repeatParallel = void 0;
const shared_1 = require("../../shared");
const BasicParallelEnumerable_1 = require("../BasicParallelEnumerable");
/**
 * Generates a sequence that contains one repeated value.
 * @param element The value to be repeated.
 * @param count The number of times to repeat the value in the generated sequence.
 * @param delay Miliseconds for Timeout
 * @returns An IParallelEnumerable<T> that contains a repeated value.
 */
function repeatParallel(
// eslint-disable-next-line no-shadow
element, count, delay) {
    if (count < 0) {
        throw new shared_1.ArgumentOutOfRangeException(`count`);
    }
    if (delay) {
        return repeat2(element, count, delay);
    }
    else {
        return repeat1(element, count);
    }
}
exports.repeatParallel = repeatParallel;
const repeat1 = (element, count) => {
    const generator = async () => {
        const values = new Array(count);
        for (let i = 0; i < count; i++) {
            values[i] = element;
        }
        return values;
    };
    return new BasicParallelEnumerable_1.BasicParallelEnumerable({
        generator,
        type: 0 /* PromiseToArray */,
    });
};
const repeat2 = (element, count, delay) => {
    const generator = async () => {
        const values = new Array(count);
        for (let i = 0; i < count; i++) {
            values[i] = new Promise((resolve) => setTimeout(() => resolve(element), delay));
        }
        return values;
    };
    return new BasicParallelEnumerable_1.BasicParallelEnumerable({
        generator,
        type: 2 /* PromiseOfPromises */,
    });
};
