"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.firstAsync = void 0;
const shared_1 = require("../../shared");
/**
 * Returns the first element in a sequence that satisfies a specified condition.
 * @param source An Iterable<T> to return an element from.
 * @param predicate A function to test each element for a condition.
 * @throws {InvalidOperationException} No elements in Iteration matching predicate
 * @returns The first element in the sequence that passes the test in the specified predicate function.
 */
exports.firstAsync = async (source, predicate) => {
    for (const value of source) {
        if (await predicate(value) === true) {
            return value;
        }
    }
    throw new shared_1.InvalidOperationException(shared_1.ErrorString.NoMatch);
};
