"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toMap = void 0;
/**
 * Converts an Iterable<V> to a Map<K, V[]>.
 * @param source An Iterable<V> to convert.
 * @param selector A function to serve as a key selector.
 * @returns Map<K, V[]>
 */
exports.toMap = (source, selector) => {
    const map = new Map();
    for (const value of source) {
        const key = selector(value);
        const array = map.get(key);
        if (array === undefined) {
            map.set(key, [value]);
        }
        else {
            array.push(value);
        }
    }
    return map;
};
