"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isEnumerable = void 0;
const ArrayEnumerable_1 = require("./ArrayEnumerable");
const BasicEnumerable_1 = require("./BasicEnumerable");
/* eslint-disable @typescript-eslint/no-unsafe-assignment, @typescript-eslint/no-unsafe-member-access */
/**
 * Determine if a source is a IEnumerable
 * @param source Any Value
 * @returns Whether or not this is an Enumerable type
 */
exports.isEnumerable = (source) => {
    if (!source) {
        return false;
    }
    if (source instanceof BasicEnumerable_1.BasicEnumerable) {
        return true;
    }
    if (source instanceof ArrayEnumerable_1.ArrayEnumerable) {
        return true;
    }
    if (typeof source[Symbol.iterator] !== "function") {
        return false;
    }
    const propertyNames = Object.getOwnPropertyNames(BasicEnumerable_1.BasicEnumerable.prototype)
        .filter((v) => v !== "constructor");
    const methods = source.prototype || source;
    for (const prop of propertyNames) {
        if (typeof methods[prop] !== "function") {
            return false;
        }
    }
    return true;
};
